local shader = love.graphics.newShader[[
  extern Image background;

  vec4 effect(vec4 colour, Image texture, vec2 texpos, vec2 scrpos)
  {
    vec4 fgpixel = Texel(texture, texpos) * colour;
    vec4 bgpixel = Texel(background, scrpos/love_ScreenSize.xy);
    return vec4(fgpixel.rgb - bgpixel.rgb, fgpixel.a);
  }
]]

local x = 300
local y = 400

local vx = 1000
local vy = 1000

local vxoffset = 0
local vyoffset = 0

local img = love.graphics.newImage('backg.jpg')

local radius = 40

local regHits = 0
local cornHits = 0
local duelCount = 0

local leftHit = false
local rightHit = false
local topHit = false
local bottomHit = false

local lastHit = 'None'

rand = 0

function ran()
	rand = math.random(-30,30)
	return rand
end

function love.update(dt)
  x = x + vx * dt
  y = y + vy * dt
  if x > love.graphics.getWidth() - radius then
    vx = -vx + ran()
    x = love.graphics.getWidth() - radius
	regHits = regHits + 1
	rightHit = true
	lastHit = 'Right'
  end
  if y > love.graphics.getHeight() - radius then
    vy = -vy + ran()
    y = love.graphics.getHeight() - radius
	regHits = regHits + 1
	bottomHit = true
	lastHit = 'Bottom'
  end
  if x < radius then
    vx = -vx + ran()
    x = radius
	regHits = regHits + 1
	leftHit = true
	lastHit = 'Left'
  end
  if y < radius then
    vy = -vy + ran()
    y = radius
	regHits = regHits + 1
	topHit = true
	lastHit = 'Top'
  end
  
  if topHit and leftHit then
	duelCount = duelCount + 1
	regHits = regHits - 2
  end
  if topHit and rightHit then
	duelCount = duelCount + 1
	regHits = regHits - 2
  end
  if bottomHit and leftHit then
	duelCount = duelCount + 1
	regHits = regHits - 2
  end
  if bottomHit and rightHit then
	duelCount = duelCount + 1
	regHits = regHits - 2
  end
  leftHit = false
  rightHit = false
  topHit = false
  bottomHit = false
end

function love.draw()
  love.graphics.draw(img)
  love.graphics.print("Regular Hits: "..regHits, 5, 5)
  love.graphics.print("Corner Hits: "..cornHits, 5, 20)
  love.graphics.print("Previous hit: "..lastHit, 5, 35)
  love.graphics.print("Resolution: 1280x720", 5, 65)
  love.graphics.print("Radius: "..radius, 5, 80)
  love.graphics.print("X: "..math.floor(x), 5, 110)
  love.graphics.print("Y: "..math.floor(y), 5, 125)
  love.graphics.print("VX: "..vx, 5, 140)
  love.graphics.print("VY: "..vy, 5, 155)
  love.graphics.print("VX Offset: "..vxoffset, 5, 180)
  love.graphics.print("VY Offset: "..vyoffset, 5, 195)
  love.graphics.print("Random Offset: "..rand, 5, 210)
  shader:send('background', img)
  love.graphics.setShader(shader)
  love.graphics.circle("fill", x, y, radius)
  love.graphics.setShader()
end

function love.keypressed(key)
	if key == "1" then
		vx = vx + 10
		vxoffset = vxoffset + 10
	end
	if key == "2" then
		vx = vx - 10
		vxoffset = vxoffset - 10
	end
	if key == "3" then
		vy = vy + 10
		vyoffset = vyoffset + 10
	end
	if key == "4" then
		vy = vy - 10
		vyoffset = vyoffset - 10
	end
end